# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PlaidLinkRequest(UniversalBaseModel):
    account_id: str = pydantic.Field(alias="accountId")
    """
    Plaid account ID
    """

    public_token: typing.Optional[str] = pydantic.Field(alias="publicToken", default=None)
    """
    Public token received from Plaid Link. Use this if linking the account using the Plaid Link frontend component.
    """

    access_token: typing.Optional[str] = pydantic.Field(alias="accessToken", default=None)
    """
    Plaid access token for the account. If you already have an access token for the account (for example, you have linked the account to your app already), use this instead of publicToken.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from .currency_code import CurrencyCode
from .payment_method_balance_status import PaymentMethodBalanceStatus
import typing
import datetime as dt
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PaymentMethodBalanceResponse(UniversalBaseModel):
    available_balance: float = pydantic.Field(alias="availableBalance")
    currency: CurrencyCode
    status: PaymentMethodBalanceStatus = pydantic.Field()
    """
    If the status is UNAVAILABLE, the account does not support this operation. If the status is ERROR, the account may need to be re-linked with Plaid.
    """

    updated_at: typing.Optional[dt.datetime] = pydantic.Field(alias="updatedAt", default=None)
    """
    The time the balance was last updated. Will be null if the balance has never been updated.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
from ...payment_method_types.types.currency_code import CurrencyCode
import typing
from .invoice_metrics_per_date_response import InvoiceMetricsPerDateResponse
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class InvoiceMetricsResponse(UniversalBaseModel):
    """
    Examples
    --------
    import datetime

    from mercoa.invoice_types import (
        InvoiceMetricsPerDateResponse,
        InvoiceMetricsResponse,
    )

    InvoiceMetricsResponse(
        total_amount=1000.0,
        total_count=10,
        average_amount=100.0,
        currency="USD",
        dates={
            "2021-01-01T00:00:00Z": InvoiceMetricsPerDateResponse(
                date=datetime.datetime.fromisoformat(
                    "2021-01-01 00:00:00+00:00",
                ),
                total_amount=100.0,
                total_count=1,
                average_amount=100.0,
                currency="USD",
            ),
            "2021-01-02T00:00:00Z": InvoiceMetricsPerDateResponse(
                date=datetime.datetime.fromisoformat(
                    "2021-01-02 00:00:00+00:00",
                ),
                total_amount=200.0,
                total_count=2,
                average_amount=100.0,
                currency="USD",
            ),
            "2021-01-03T00:00:00Z": InvoiceMetricsPerDateResponse(
                date=datetime.datetime.fromisoformat(
                    "2021-01-03 00:00:00+00:00",
                ),
                total_amount=400.0,
                total_count=2,
                average_amount=200.0,
                currency="USD",
            ),
        },
    )
    """

    total_amount: float = pydantic.Field(alias="totalAmount")
    total_count: int = pydantic.Field(alias="totalCount")
    average_amount: float = pydantic.Field(alias="averageAmount")
    currency: CurrencyCode
    dates: typing.Optional[typing.Dict[str, InvoiceMetricsPerDateResponse]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
